| plot_dist | R Documentation |
Plot Distribution
plot_dist(...)
... |
Distributional object(s) to plot. When passing multiple objects naming them will change the labels in the plot, else they will use the distributional format |
ggplot object that is the density of the provided distribution
library(distributional)
plot_dist(dist_normal(0, 1))
plot_dist(dist_multivariate_normal(mu = list(c(1, 2)), sigma = list(matrix(c(4, 2, 2, 3), ncol=2))))
#Plotting Multiple
plot_dist(dist_normal(0, 1), dist_normal(10, 5))
plot_dist('Prior' = dist_normal(0, 1), 'Posterior' = dist_normal(10, 5))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.